import koji
import fedmsg
import fedmsg.encoding

from . import config, JobTrigger, TriggerMsgError

ITEM_TYPE = 'koji_build'


def get_item(msg):
    release = msg['msg']['release']
    state = msg['msg']['new']
    instance = msg['msg']['instance']

    name = msg['msg']['name']
    version = msg['msg']['version']

    envr = "%s-%s-%s" % (name, version, release)

    if not instance == 'primary':
        raise TriggerMsgError('rejecting message not from primary koji instance (%s from %s)' % (envr, instance))

    if state != koji.BUILD_STATES['COMPLETE']:
        raise TriggerMsgError('rejecting message for not being a build complete message (%s, status %s)' % (envr, state))

    if 'fc' not in release:
        raise TriggerMsgError('rejecting message for not containing "fc" in release (%s)' % envr)

    return envr


class KojiBuildCompletedJobTrigger(JobTrigger):
    topic = "org.fedoraproject.prod.buildsys.build.state.change"
    jsonify = False
    config_key = 'taskotron.kojibuildcompletedjobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(KojiBuildCompletedJobTrigger, self).__init__(*args, **kw)

    def consume(self, message):
        msg = fedmsg.encoding.loads(message.body)

        try:
            item = get_item(msg)
            self.trigger_tasks(item, ITEM_TYPE, config.koji_build_completed_tasks, config.valid_arches)
        except TriggerMsgError, e:
            self.log.debug(e)
